@@ -11,66 +11,7 @@ NULL
 # return a plot if geomfunc!=Null or a list(option, mapping) if  geomfunc = NULL
 .geom_exec <- function (geomfunc = NULL, data = NULL,
                         position = NULL, ...) {
-  params <- list(...)
-
-  mapping <-
-    list() # option to pass to mapping aes() or aes_string()
-  option <- list() # option to the geom_*()
-
-  allowed_options <- c(
-    # general
-    "color", "colour", "linetype", "fill", "size", "shape", "width",
-    "alpha", "na.rm", "lwd", "pch", "cex", "position", "stat", "geom",
-    "show.legend", "inherit.aes", "fun.args", "fontface",
-    # boxplot
-    "outlier.colour", "outlier.shape", "outlier.size",
-    "outlier.stroke", "notch", "notchwidth", "varwidth",
-    # dot plot
-    "binwidth", "binaxis", "method", "binpositions",
-    "stackdir", "stackratio", "dotsize",
-    # Violin
-    "trim", "draw_quantiles", "scale",
-    # error
-    "ymin", "ymax", "xmin", "xmax",
-    # text
-    "label", "hjust", "vjust", "fontface",
-    # smooth
-    "se", "level", "fullrange",
-    "conf.int.level",
-    # straightline
-    "xintercept", "yintercept",
-    # histograms
-    "bins",
-    # rug
-    "sides"
-
-  )
-
-  columns <- colnames(data)
-  for (key in names(params)) {
-    value <- params[[key]]
-    if (is.null(value)) {
-
-    }
-    else if (value[1] %in% columns) {
-      mapping[[key]] <- value
-
-    }
-  else if (key %in% allowed_options) {
-      option[[key]] <- value
-    }
-    # else warnings("Don't know '", key, "'")
-  }
-  if (!is.null(position))
-  option[["position"]] <- position
-  option[["data"]] <- data
-  if(is.null(geomfunc)){
-    return(list(option = option, mapping = mapping))
-  }
-  else{
-  option[["mapping"]] <- do.call(ggplot2::aes_string, mapping)
-  return(do.call(geomfunc, option))
-  }
+  geom_exec(geomfunc = geomfunc, data = data, position = position, ...)
 }
 
 # %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -149,10 +90,8 @@ NULL
 # Graphical parameters
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-# Change color manually
-# possible value for palette: brewer palette, "grey" or a vector of colors
-.ggcolor <- function(palette = NULL, ...) {
-  brewerpal <- c(
+.brewerpal <- function(){
+  c(
     # sequential
     'Blues', 'BuGn', 'BuPu', 'GnBu', 'Greens', 'Greys', 'Oranges',
     'OrRd', 'PuBu', 'PuBuGn', 'PuRd', 'Purples', 'RdPu', 'Reds',
@@ -162,11 +101,25 @@ NULL
     # Qualitative
     'Accent', 'Dark2', 'Paired', 'Pastel1', 'Pastel2', 'Set1', 'Set2', 'Set3'
   )
-
+}
+.ggscipal <- function(){
   # Scientific Journal and Sci-Fi Themed Color Palettes for ggplot2
   # ggsci package: https://cran.r-project.org/web/packages/ggsci/vignettes/ggsci.html
-  ggscipal <- c("npg", "aaas", "lancet", "jco",
+  c("npg", "aaas", "lancet", "jco",
                 "ucscgb", "uchicago", "simpsons", "rickandmorty")
+}
+
+# Check if color palette or default hue
+.is_col_palette <- function(pal){
+  if(is.null(pal)) return(FALSE)
+  else return(length(pal)==1 & pal[1] %in% c(.brewerpal(), .ggscipal(), "default"))
+}
+
+# Change color manually
+# possible value for palette: brewer palette, "grey" or a vector of colors
+.ggcolor <- function(palette = NULL, ...) {
+  brewerpal <- .brewerpal()
+  ggscipal <- .ggscipal()
 
   res <- NULL
   if (is.null(palette))
@@ -188,21 +141,8 @@ NULL
 # Change fill color manually
 # possible value for palette: brewer palette, "grey" or a vector of colors
 .ggfill <- function(palette = NULL, ...) {
-  brewerpal <- c(
-    # sequential
-    'Blues', 'BuGn', 'BuPu', 'GnBu', 'Greens', 'Greys', 'Oranges',
-    'OrRd', 'PuBu', 'PuBuGn', 'PuRd', 'Purples', 'RdPu', 'Reds',
-    'YlGn', 'YlGnBu YlOrBr', 'YlOrRd',
-    #Divergent
-    'BrBG', 'PiYG', 'PRGn', 'PuOr', 'RdBu', 'RdGy', 'RdYlBu', 'RdYlGn', 'Spectral',
-    # Qualitative
-    'Accent', 'Dark2', 'Paired', 'Pastel1', 'Pastel2', 'Set1', 'Set2', 'Set3'
-  )
-
-  # Scientific Journal and Sci-Fi Themed Color Palettes for ggplot2
-  # ggsci package: https://cran.r-project.org/web/packages/ggsci/vignettes/ggsci.html
-  ggscipal <- c("npg", "aaas", "lancet", "jco",
-                "ucscgb", "uchicago", "simpsons", "rickandmorty")
+  brewerpal <- .brewerpal()
+  ggscipal <- .ggscipal()
 
   res <- NULL
   if (is.null(palette))
@@ -263,6 +203,82 @@ NULL
   functs[[pal]]
 }
 
+# Generate color palette from ggsci or Rcolorbrewer
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+# pal could be a brewer or ggsci palette
+.get_pal <- function(pal = "default", k){
+ if(pal %in% .brewerpal()) .get_brewer_pal(pal, k)
+  else if(pal %in% .ggscipal()) .get_ggsci_pal(pal, k)
+  else if(pal == "default"){
+    hues <- seq(15, 375, length = k + 1)
+    grDevices::hcl(h = hues, l = 65, c = 100, alpha = 1)[1:k]
+  }
+}
+
+# Generate color palette from ggsci
+# k the number of color
+.get_ggsci_pal <- function(palette = c("npg", "aaas", "lancet", "jco",
+                                           "ucscgb", "uchicago", "simpsons", "rickandmorty"), k)
+{
+
+  pal <- match.arg(palette)
+
+  if(pal %in% c("npg", "aaas", "jco")) max_k <- 10
+  else if (pal %in% c("lancet", "uchicago")) max_k <- 9
+  else if (pal %in% c("ucscgb")) max_k <- 26
+  else if (pal %in% c("simpsons")) max_k <- 16
+  else if (pal %in% c("rickandmorty")) max_k <- 12
+  else stop("Don't support palette name: ", pal)
+
+  functs <- list(
+    npg = ggsci::pal_npg(),
+    aaas = ggsci::pal_aaas(),
+    lancet = ggsci::pal_lancet(),
+    jco = ggsci::pal_jco(),
+    ucscgb = ggsci::pal_ucscgb(),
+    uchicago = ggsci::pal_uchicago(),
+    simpsons = ggsci::pal_simpsons(),
+    rickandmorty = ggsci::pal_rickandmorty()
+  )
+
+  if(k <= max_k) functs[[pal]](k)
+  else grDevices::colorRampPalette(functs[[pal]](max_k))(k)
+}
+
+# Generate a color palette from brewer
+.get_brewer_pal <- function(palette, k){
+  if (!requireNamespace("RColorBrewer", quietly = TRUE)) {
+    stop("RColorBrewer package needed. Please install it using install.packages('RColorBrewer').")
+  }
+  pal <- palette[1]
+  sequential <- c('Blues', 'BuGn', 'BuPu', 'GnBu', 'Greens', 'Greys', 'Oranges',
+    'OrRd', 'PuBu', 'PuBuGn', 'PuRd', 'Purples', 'RdPu', 'Reds','YlGn', 'YlGnBu YlOrBr', 'YlOrRd')
+  divergent <- c('BrBG', 'PiYG', 'PRGn', 'PuOr', 'RdBu', 'RdGy', 'RdYlBu', 'RdYlGn', 'Spectral')
+
+  if(pal %in% sequential) max_k <- 9
+  else if(pal %in% divergent) max_k <- 11
+  else if(pal %in% c('Accent','Dark2','Pastel2', 'Set2')) max_k <- 8
+  else if(pal %in% c('Pastel1',  'Set1')) max_k <- 9
+  else if(pal %in% c('Paired', 'Set3')) max_k <- 12
+  else stop("Don't support palette name: ", pal)
+
+  if(k <= max_k) RColorBrewer::brewer.pal(k, palette)
+  else grDevices::colorRampPalette(RColorBrewer::brewer.pal(max_k, palette))(k)
+}
+
+# Set gradient colors
+# cols a vector of colors
+.gradient_col <- function (cols){
+  if(.is_col_palette(cols)) cols <- .get_pal(cols, k = 3)
+  n_cols <- length(cols)
+
+  if(n_cols == 1) {
+    cols <- grDevices::colorRampPalette(c("white", cols))(10)
+    cols <- cols[c(1, 10)]
+    n_cols <- 2
+  }
+  ggplot2::scale_color_gradientn(colours = cols)
+}
 
 # Set plot orientation
 # %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -339,20 +355,24 @@ NULL
   function(ticks = TRUE, tickslab = TRUE, font.tickslab = NULL,
            xtickslab.rt = 0, ytickslab.rt = 0)
   {
+
+    if(xtickslab.rt > 5) xhjust <- 1 else xhjust <- NULL
+
     if (ticks)
       ticks <-
         element_line(colour = "black")
     else
       ticks <- element_blank()
     if (is.null(font.tickslab))
-      font <- list(size = 12, face = "bold", color = "black")
+      font <- list(size = 12, face = "plain", color = "black")
     else
       font <- .parse_font(font.tickslab)
     if (tickslab) {
       xtickslab <-
         element_text(
           size = font$size, face = font$face,
-          colour = font$color, angle = xtickslab.rt
+          colour = font$color, angle = xtickslab.rt,
+          hjust = xhjust
         )
       ytickslab <-
         element_text(
@@ -417,7 +437,7 @@ NULL
 
   else{
     if(xscale != "none")  p <- p + scale_x_continuous(trans = xscale)
-    else if(yscale != "none") p <- p + scale_y_continuous(trans = yscale)
+    if(yscale != "none") p <- p + scale_y_continuous(trans = yscale)
   }
 p
 }
@@ -526,17 +546,17 @@ p
 
 
   if ("boxplot" %in% add) {
-    size <- ifelse(is.null(add.params$size), 1, add.params$size)
+    # size <- ifelse(is.null(add.params$size), 1, add.params$size)
     p <- p + .geom_exec(geom_boxplot, data = data,
                         color = color, fill = fill,
-                        position = position, width = width, size = size)
+                        position = position, width = width, size = add.params$size)
   }
 
   if ("violin" %in% add) {
-    size <- ifelse(is.null(add.params$size), 1, add.params$size)
+    # size <- ifelse(is.null(add.params$size), 1, add.params$size)
     p <- p + .geom_exec(geom_violin, data = data, trim = FALSE,
                         color = color, fill = fill,
-                        position = position, width = width, size = size)
+                        position = position, width = width, size = add.params$size)
   }
 
 
@@ -549,18 +569,31 @@ p
   }
   if ( "jitter" %in% add ){
     set.seed(123)
-    jitter.size <- ifelse(is.null(add.params$size), 3, add.params$size)
+    # jitter.size <- ifelse(is.null(add.params$size), 2, add.params$size)
     ngrps <- length(intersect(names(data), c(.mapping["x"], fill, color)))
     if(p_geom == "geom_line" | ngrps == 1) .jitter = position_jitter(0.4)
     else if(ngrps > 1) .jitter <- position_dodge(0.8)
 
     if(!is.null(add.params$jitter)) .jitter = position_jitter(0.4)
     p <- p + .geom_exec(geom_jitter, data = data,
-                        color = color, fill = fill, shape = shape, size = jitter.size,
+                        color = color, fill = fill, shape = shape, size = add.params$size,
                         position = .jitter )
 
   }
 
+  if ( "point" %in% add ) {
+    p <- p + .geom_exec(geom_point, data = data,
+                        color = color,  size = add.params$size,
+                        position = position)
+
+  }
+  if ( "line" %in% add ) {
+    p <- p + .geom_exec(geom_line, data = data, group = 1,
+                        color = color,  size = add.params$size,
+                        position = position)
+
+  }
+
 
   # Add mean or median
   center <- intersect(c("mean", "median"), add)
@@ -679,6 +712,46 @@ p
   }
 }
 
+# Check th data provided by user
+# return a list(data, x, y)
+.check_data <- function(data, x, y){
+
+  if(missing(x) & missing(y)){
+    if(!is.numeric(data))
+      stop("x and y are missing. In this case data should be a numeric vector.")
+    else{
+      data <- data.frame(y = data, x = rep(1, length(data)))
+      x <- "x"
+      y <- "y"
+    }
+  }
+  else if(missing(x)) {
+    x <- "x"
+    if(is.numeric(data)) data <- data.frame(x = data)
+    else data$x <- rep("1", nrow(data))
+  }
+  list(data = data, x =x, y = y)
+}
+
+
+# Adjust shape when ngroups > 6, to avoid ggplot warnings
+.scale_point_shape <- function(p, data, shape){
+  if(shape %in% colnames(data)){
+    grp <- data[, shape]
+    if(!inherits(grp, "factor")) grp <- as.factor(grp)
+    ngroups <- length(levels(data[, shape]))
+    if(ngroups > 6) p <- p + scale_shape_manual(values=1:ngroups, labels = levels(data[, shape]))
+  }
+  p
+}
+
+# Get not numeric columns in a data.frame
+.get_not_numeric_vars <- function(data_frame){
+  is_numeric <- sapply(data_frame, is.numeric)
+  if(sum(!is_numeric) == 0) res = NULL
+  else res <- colnames(data_frame[, !is_numeric, drop = FALSE])
+  res
+}
 
 
 
